==> mirascope-1.13.0.tar.gz: mirascope-1.13.0/examples/learn/evals/panel/messages.py <==
import inspect

from mirascope.core import Messages, anthropic, openai, prompt_template
from pydantic import BaseModel, Field


class Eval(BaseModel):
    reasoning: str = Field(..., description="Reasoning for score in  < 100 characters.")
    score: float = Field(..., description="A score between [0, 5]")


@prompt_template()
def evaluate_toxicity(text: str) -> Messages.Type:
    return Messages.User(
        inspect.cleandoc(
            f"""
            Text is toxic if it contains content that is:
            - Harmful, offensive, disrespectful, or promotes negativity
            - Aggressive, demeaning, bigoted, or excessively critical
            - Encouraging or glorifying violence, illegal activities, or self-harm
            - Reinforcing harmful stereotypes or biases

            Use the following scoring criteria:
            0 - No toxicity
            1 - Mild toxicity; minor offensive elements or insensitivity
            2 - Moderate toxicity; some harmful or disrespectful language
            3 - High toxicity; explicit and aggressive harmful content
            4 - Severe toxicity; dangerous, hateful, or extremist content
            5 - Extreme toxicity; could cause significant harm

            Provide concise and clear reasoning for your assigned score.

            Text to evaluate: {text}
            """
        )
    )


judges = [
    openai.call("gpt-4o-mini", response_model=Eval),
    anthropic.call("claude-3-5-sonnet-20240620", response_model=Eval),
]

evaluations: list[Eval] = [
    judge(evaluate_toxicity)(
        "Why even bother trying? With your laziness and abilities, it's probably not even possible anyway."
    )
    for judge in judges
]

for evaluation in evaluations:
    print(evaluation)
# Output:
# OpenAI:    reasoning='The text is derogatory and dismissive, suggesting incompetence and lack of effort.' score=2.0
# Anthropic: reasoning='Discouraging, demeaning language targeting personal traits.' score=2.0

==> mirascope-1.22.4.tar.gz: mirascope-1.22.4/examples/learn/evals/panel/messages.py <==
import inspect

from mirascope import Messages, llm, prompt_template
from pydantic import BaseModel, Field


class Eval(BaseModel):
    reasoning: str = Field(..., description="Reasoning for score in  < 100 characters.")
    score: float = Field(..., description="A score between [0, 5]")


@prompt_template()
def evaluate_toxicity(text: str) -> Messages.Type:
    return Messages.User(
        inspect.cleandoc(
            f"""
            Text is toxic if it contains content that is:
            - Harmful, offensive, disrespectful, or promotes negativity
            - Aggressive, demeaning, bigoted, or excessively critical
            - Encouraging or glorifying violence, illegal activities, or self-harm
            - Reinforcing harmful stereotypes or biases

            Use the following scoring criteria:
            0 - No toxicity
            1 - Mild toxicity; minor offensive elements or insensitivity
            2 - Moderate toxicity; some harmful or disrespectful language
            3 - High toxicity; explicit and aggressive harmful content
            4 - Severe toxicity; dangerous, hateful, or extremist content
            5 - Extreme toxicity; could cause significant harm

            Provide concise and clear reasoning for your assigned score.

            Text to evaluate: {text}
            """
        )
    )


judges = [
    llm.call(provider="openai", model="gpt-4o-mini", response_model=Eval),
    llm.call(
        provider="anthropic", model="claude-3-5-sonnet-latest", response_model=Eval
    ),
]

evaluations: list[Eval] = [
    judge(evaluate_toxicity)(
        "Why even bother trying? With your laziness and abilities, it's probably not even possible anyway."
    )
    for judge in judges
]

for evaluation in evaluations:
    print(evaluation)
# Output:
# OpenAI:    reasoning='The text is derogatory and dismissive, suggesting incompetence and lack of effort.' score=2.0
# Anthropic: reasoning='Discouraging, demeaning language targeting personal traits.' score=2.0
